==> openshift-model-hive-5.12.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/SelectorSyncSetSpecBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SelectorSyncSetSpecBuilder extends io.fabric8.openshift.api.model.hive.v1.SelectorSyncSetSpecFluentImpl<io.fabric8.openshift.api.model.hive.v1.SelectorSyncSetSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.hive.v1.SelectorSyncSetSpec,io.fabric8.openshift.api.model.hive.v1.SelectorSyncSetSpecBuilder>{
  public SelectorSyncSetSpecBuilder() {
    this(false);
  }
  public SelectorSyncSetSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new SelectorSyncSetSpec(), validationEnabled);
  }
  public SelectorSyncSetSpecBuilder(io.fabric8.openshift.api.model.hive.v1.SelectorSyncSetSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public SelectorSyncSetSpecBuilder(io.fabric8.openshift.api.model.hive.v1.SelectorSyncSetSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SelectorSyncSetSpec(), validationEnabled);
  }
  public SelectorSyncSetSpecBuilder(io.fabric8.openshift.api.model.hive.v1.SelectorSyncSetSpecFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.SelectorSyncSetSpec instance) {
    this(fluent, instance, false);
  }
  public SelectorSyncSetSpecBuilder(io.fabric8.openshift.api.model.hive.v1.SelectorSyncSetSpecFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.SelectorSyncSetSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApplyBehavior(instance.getApplyBehavior()); 
    fluent.withClusterDeploymentSelector(instance.getClusterDeploymentSelector()); 
    fluent.withPatches(instance.getPatches()); 
    fluent.withResourceApplyMode(instance.getResourceApplyMode()); 
    fluent.withResources(instance.getResources()); 
    fluent.withSecretMappings(instance.getSecretMappings()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SelectorSyncSetSpecBuilder(io.fabric8.openshift.api.model.hive.v1.SelectorSyncSetSpec instance) {
    this(instance,false);
  }
  public SelectorSyncSetSpecBuilder(io.fabric8.openshift.api.model.hive.v1.SelectorSyncSetSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApplyBehavior(instance.getApplyBehavior()); 
    this.withClusterDeploymentSelector(instance.getClusterDeploymentSelector()); 
    this.withPatches(instance.getPatches()); 
    this.withResourceApplyMode(instance.getResourceApplyMode()); 
    this.withResources(instance.getResources()); 
    this.withSecretMappings(instance.getSecretMappings()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.hive.v1.SelectorSyncSetSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.hive.v1.SelectorSyncSetSpec build() {
    SelectorSyncSetSpec buildable = new SelectorSyncSetSpec(fluent.getApplyBehavior(),fluent.getClusterDeploymentSelector(),fluent.getPatches(),fluent.getResourceApplyMode(),fluent.getResources(),fluent.getSecretMappings());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SelectorSyncSetSpecBuilder that = (SelectorSyncSetSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-hive-6.6.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/SelectorSyncSetSpecBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class SelectorSyncSetSpecBuilder extends SelectorSyncSetSpecFluentImpl<SelectorSyncSetSpecBuilder> implements VisitableBuilder<SelectorSyncSetSpec,SelectorSyncSetSpecBuilder>{
  public SelectorSyncSetSpecBuilder() {
    this(false);
  }
  public SelectorSyncSetSpecBuilder(Boolean validationEnabled) {
    this(new SelectorSyncSetSpec(), validationEnabled);
  }
  public SelectorSyncSetSpecBuilder(SelectorSyncSetSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public SelectorSyncSetSpecBuilder(SelectorSyncSetSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new SelectorSyncSetSpec(), validationEnabled);
  }
  public SelectorSyncSetSpecBuilder(SelectorSyncSetSpecFluent<?> fluent,SelectorSyncSetSpec instance) {
    this(fluent, instance, false);
  }
  public SelectorSyncSetSpecBuilder(SelectorSyncSetSpecFluent<?> fluent,SelectorSyncSetSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApplyBehavior(instance.getApplyBehavior()); 
    fluent.withClusterDeploymentSelector(instance.getClusterDeploymentSelector()); 
    fluent.withPatches(instance.getPatches()); 
    fluent.withResourceApplyMode(instance.getResourceApplyMode()); 
    fluent.withResources(instance.getResources()); 
    fluent.withSecretMappings(instance.getSecretMappings()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SelectorSyncSetSpecBuilder(SelectorSyncSetSpec instance) {
    this(instance,false);
  }
  public SelectorSyncSetSpecBuilder(SelectorSyncSetSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApplyBehavior(instance.getApplyBehavior()); 
    this.withClusterDeploymentSelector(instance.getClusterDeploymentSelector()); 
    this.withPatches(instance.getPatches()); 
    this.withResourceApplyMode(instance.getResourceApplyMode()); 
    this.withResources(instance.getResources()); 
    this.withSecretMappings(instance.getSecretMappings()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  SelectorSyncSetSpecFluent<?> fluent;
  Boolean validationEnabled;
  public SelectorSyncSetSpec build() {
    SelectorSyncSetSpec buildable = new SelectorSyncSetSpec(fluent.getApplyBehavior(),fluent.getClusterDeploymentSelector(),fluent.getPatches(),fluent.getResourceApplyMode(),fluent.getResources(),fluent.getSecretMappings());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
